# SAC-Tello
A simple library for controlling a DJI Tello Drone. Built for educational use.

# Dependencies

> numpy>=1.23.4"
> 
> opencv-python>=4.6.0.66
> 
> face_recognition>=1.3.0
> 
> pygame>=2.2.0